==> BestCrypt-2.0.7.tar.gz: BestCrypt-2.0.7/certificate/CertificateLib/SMemory/cPassword.h <==
/////////////////////////////////////////////////////////////////
//
//	Copyright (c) 1994-2005 Jetico, Inc., Finland
//	All rights reserved.
//
//	File: cPassword.h
//	Revision: 
//	Created:	12.05.2005
//	Description: 
//		cPassword
//			Class for storing character string for password.
//			It has buffer with predefined size.
//			Destructor clears allocated memory buffer.
//
//
/////////////////////////////////////////////////////////////////

#ifndef _cPassword_h_
#define _cPassword_h_

//#include <windows.h>
#include "../publicKeyAlgs/Power/Windefs.h"
#include "SBlocks.h"
#include <assert.h>

class cPassword : public cUniversalString
{
  public:
	enum { MaxLenght = 256, MinimumLenght = 8 };

	void InitBuffers();

	cPassword( const char *pwdStr = NULL );
	cPassword( const wchar_t *pwdStr );

	~cPassword();

	bool IsEmpty() const { return getLengthUTF8() == 0; }

	int getLengthUTF8() const
	{
		if ( buffer == NULL )
			return 0;

		if ( bufferSize == 0 )
			return 0;

		int len = 0;

		for( ; len < bufferSize; len++ )
		{
			if ( buffer[len] == '\0' )
				break;
		}

		return len;
	}

	bool CheckValidSize();
	bool wcCheckValidSize();


	//
	//	Returns difference of first not matched symbols.
	//
	int Compare( cPassword *pwd );
	int wcCompare( cPassword *pwd );

	//
	//	generateKeyFromPassword
	//		Uses P12_producePseudoRandomBytes functions for key generation.
	//
	bool generateKeyFromPassword(
		BYTE *outBuff,	int outBuffSize,
		BYTE hashAlgId, // = bchaSHA256,
		BYTE *salt,		int saltSize, // NULL
		int iteration, // == 1
		bool key // key or IV
	);

	//
	//	The module which uses the function is responsible 
	//	for including the "UnicodeFuncs.h" first
	//
#ifdef _WIN32
#ifdef _UnicodeFuncs_
	//
	//	ReadFromEditBox
	//		1. Reads wide char text from edit box to wcBuffer,
	//		2. Generates UTF-8 encoded string to the buffer from wcBuffer,
	//		3. Generates UTF-16 unicode string to unicodeBuffer from wcBuffer.
	//
	int ReadFromEditBox( HWND hEB )
	{
		memset( wcBuffer, 0, wcBufferSize );
		int maxLen = wcBufferSize / sizeof( wchar_t );
		GetWindowTextT( hEB, wcBuffer, maxLen );
		//
		//	BCArchive v. 2.06.4 - 16.10.2014
		//	CertificateLib v. 1.04.3 - 16.10.2014
		//		Bug #1687 v2.06.3 cannot open old archives with long passwords
		//
		//	Old archive cleared 255-th symbol.
		// wcBuffer[maxLen-1] = L'\0';
		wcBuffer[maxLen-2] = L'\0';

		if ( WideCharToMultiByte( CP_UTF8, 0, wcBuffer, -1, buffer, bufferSize, NULL, NULL )  == 0 )
		{
			assert( false );
			// Widows 95 does not support UTF-8
			GetWindowTextA( hEB, buffer, bufferSize );
		}

		return wstr2unicodeBuff( wcBuffer );
	}

	//
	//	ReadFromEditBuffer
	//		1. Fills wcBuffer,
	//		2. Generates UTF-8 encoded string to the buffer from wcBuffer,
	//		3. Generates UTF-16 unicode string to unicodeBuffer from wcBuffer.
	//
	int ReadFromBuffer( wchar_t *buff, UINT cp = CP_UTF8, bool bOldModeCompatible = false )
	{
		if ( bOldModeCompatible )
			return GetOldVersionCompatible( buff, cp );

		memset( wcBuffer, 0, wcBufferSize );
		wcsncpy_s( wcBuffer, wcBufferSize / sizeof( wchar_t ), buff, _TRUNCATE );

		if ( WideCharToMultiByte( cp, 0, wcBuffer, -1, buffer, bufferSize, NULL, NULL ) == 0 )
		{
			assert( false );

			// Widows 95 does not support UTF-8 but supports ANSI code page
			if ( WideCharToMultiByte( CP_ACP, 0, wcBuffer, -1, buffer, bufferSize, NULL, NULL ) == 0 )
			{
				assert( false );
				return 0;
			}
		}

		return wstr2unicodeBuff( wcBuffer );
	}

	int GetOldVersionCompatible( wchar_t *buff, UINT cp = CP_UTF8 )
	{
		if ( buff == NULL )
			buff = wcBuffer;

		for( int i = (int)wcslen( buff ); i >= 0; i-- )
		{
			if ( ( buff[i] & 0xFF00 ) == 0x0400 ) // Russian encoding
			{
				if ( buff[i] == 0x51 ) // russian 'your'
					buff[i] = 0xb8;
				else
					buff[i] += 0xb0;
			}

			wcBuffer[i] = (wchar_t)(char)buff[i];
		}
				
		if ( WideCharToMultiByte( cp, 0, wcBuffer, -1, buffer, bufferSize, NULL, NULL ) == 0 )
		{
			assert( false );

			// Widows 95 does not support UTF-8 but supports ANSI code page
			if ( WideCharToMultiByte( CP_ACP, 0, wcBuffer, -1, buffer, bufferSize, NULL, NULL ) == 0 )
			{
				assert( false );
				return 0;
			}
		}

		return wstr2unicodeBuff( wcBuffer );
	}

#endif
#endif
};

#endif /* _cPassword_h_*/

==> BestCrypt-2.0.14.tar.gz: BestCrypt-2.0.14/certificate/CertificateLib/SMemory/cPassword.h <==
/////////////////////////////////////////////////////////////////
//
//	Copyright (c) 1994-2005 Jetico, Inc., Finland
//	All rights reserved.
//
//	File: cPassword.h
//	Revision: 
//	Created:	12.05.2005
//	Description: 
//		cPassword
//			Class for storing character string for password.
//			It has buffer with predefined size.
//			Destructor clears allocated memory buffer.
//
//
/////////////////////////////////////////////////////////////////

#ifndef _cPassword_h_
#define _cPassword_h_

//#include <windows.h>
#include "../publicKeyAlgs/Power/Windefs.h"
#include "SBlocks.h"
#include <assert.h>

class cPassword : public cUniversalString
{
  public:
	//enum { MaxLenght = 256, MinimumLenght = 8 };
	enum { MaxLenght = 512, MinimumLenght = 8 };

	void InitBuffers();

	cPassword( const char *pwdStr = NULL );
	cPassword( const wchar_t *pwdStr );

	~cPassword();

	bool IsEmpty() const { return getLengthUTF8() == 0; }

	int getLengthUTF8() const
	{
		if ( buffer == NULL )
			return 0;

		if ( bufferSize == 0 )
			return 0;

		int len = 0;

		for( ; len < bufferSize; len++ )
		{
			if ( buffer[len] == '\0' )
				break;
		}

		return len;
	}

	bool CheckValidSize();
	bool wcCheckValidSize();


	//
	//	Returns difference of first not matched symbols.
	//
	int Compare( cPassword *pwd );
	int wcCompare( cPassword *pwd );

	//
	//	generateKeyFromPassword
	//		Uses P12_producePseudoRandomBytes functions for key generation.
	//
	bool generateKeyFromPassword(
		BYTE *outBuff,	int outBuffSize,
		BYTE hashAlgId, // = bchaSHA256,
		BYTE *salt,		int saltSize, // NULL
		int iteration, // == 1
		bool key // key or IV
	);

	//
	//	The module which uses the function is responsible 
	//	for including the "UnicodeFuncs.h" first
	//
#ifdef _WIN32
#ifdef _UnicodeFuncs_
	//
	//	ReadFromEditBox
	//		1. Reads wide char text from edit box to wcBuffer,
	//		2. Generates UTF-8 encoded string to the buffer from wcBuffer,
	//		3. Generates UTF-16 unicode string to unicodeBuffer from wcBuffer.
	//
	int ReadFromEditBox( HWND hEB )
	{
		memset( wcBuffer, 0, wcBufferSize );
		int maxLen = wcBufferSize / sizeof( wchar_t );
		GetWindowTextT( hEB, wcBuffer, maxLen );
		//
		//	BCArchive v. 2.06.4 - 16.10.2014
		//	CertificateLib v. 1.04.3 - 16.10.2014
		//		Bug #1687 v2.06.3 cannot open old archives with long passwords
		//
		//	Old archive cleared 255-th symbol.
		// wcBuffer[maxLen-1] = L'\0';
		wcBuffer[maxLen-2] = L'\0';

		if ( WideCharToMultiByte( CP_UTF8, 0, wcBuffer, -1, buffer, bufferSize, NULL, NULL )  == 0 )
		{
			assert( false );
			// Widows 95 does not support UTF-8
			GetWindowTextA( hEB, buffer, bufferSize );
		}

		return wstr2unicodeBuff( wcBuffer );
	}

	//
	//	ReadFromEditBuffer
	//		1. Fills wcBuffer,
	//		2. Generates UTF-8 encoded string to the buffer from wcBuffer,
	//		3. Generates UTF-16 unicode string to unicodeBuffer from wcBuffer.
	//
	int ReadFromBuffer( wchar_t *buff, UINT cp = CP_UTF8, bool bOldModeCompatible = false )
	{
		if ( bOldModeCompatible )
			return GetOldVersionCompatible( buff, cp );

		memset( wcBuffer, 0, wcBufferSize );
		wcsncpy_s( wcBuffer, wcBufferSize / sizeof( wchar_t ), buff, _TRUNCATE );

		if ( WideCharToMultiByte( cp, 0, wcBuffer, -1, buffer, bufferSize, NULL, NULL ) == 0 )
		{
			assert( false );

			// Widows 95 does not support UTF-8 but supports ANSI code page
			if ( WideCharToMultiByte( CP_ACP, 0, wcBuffer, -1, buffer, bufferSize, NULL, NULL ) == 0 )
			{
				assert( false );
				return 0;
			}
		}

		return wstr2unicodeBuff( wcBuffer );
	}

	int GetOldVersionCompatible( wchar_t *buff, UINT cp = CP_UTF8 )
	{
		if ( buff == NULL )
			buff = wcBuffer;

		for( int i = (int)wcslen( buff ); i >= 0; i-- )
		{
			if ( ( buff[i] & 0xFF00 ) == 0x0400 ) // Russian encoding
			{
				if ( buff[i] == 0x51 ) // russian 'your'
					buff[i] = 0xb8;
				else
					buff[i] += 0xb0;
			}

			wcBuffer[i] = (wchar_t)(char)buff[i];
		}
				
		if ( WideCharToMultiByte( cp, 0, wcBuffer, -1, buffer, bufferSize, NULL, NULL ) == 0 )
		{
			assert( false );

			// Widows 95 does not support UTF-8 but supports ANSI code page
			if ( WideCharToMultiByte( CP_ACP, 0, wcBuffer, -1, buffer, bufferSize, NULL, NULL ) == 0 )
			{
				assert( false );
				return 0;
			}
		}

		return wstr2unicodeBuff( wcBuffer );
	}

#endif
#endif
};

#endif /* _cPassword_h_*/
